# Generated by roxygen2: do not edit by hand

export(bugs_to_df)
export(diagnostic)
export(filter_series)
export(fit_trend)
export(format_data)
export(list_series)
export(plot_series)
export(plot_trend)
export(read_bugs)
export(read_series)
export(series_to_df)
export(w_to_rmax)
importFrom(grDevices,dev.off)
importFrom(graphics,abline)
importFrom(graphics,axTicks)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,grid)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,text)
