#' @keywords internal
"_PACKAGE"

# Imports: start ---- 
#' @importFrom grDevices dev.off
#' @importFrom graphics abline axTicks axis box grid lines mtext par points 
#' @importFrom graphics polygon text
# Imports: end ----

NULL
